@@ -1,5 +1,5 @@
 package Yahoo::Marketing::CreditCardInfo;
-# Copyright (c) 2007 Yahoo! Inc.  All rights reserved.  
+# Copyright (c) 2009 Yahoo! Inc.  All rights reserved.  
 # The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997) 
 
 use strict; use warnings;
@@ -18,6 +18,9 @@ sub _user_setable_attributes {
                  cardType
                  expMonth
                  expYear
+                 issueMonth
+                 issueNumber
+                 issueYear
                  securityCode
             /  );
 }
@@ -35,7 +38,7 @@ __PACKAGE__->mk_accessors( __PACKAGE__->_user_setable_attributes,
 1;
 =head1 SYNOPSIS
 
-See L<http://searchmarketing.yahoo.com/developer/docs/V4/reference/dataObjects.php> for documentation of the various data objects.
+See L<http://searchmarketing.yahoo.com/developer/docs/V5/reference/dataObjects.php> for documentation of the various data objects.
 
 
 =cut
