@@ -1,5 +1,5 @@
 package Yahoo::Marketing::ForecastResponse;
-# Copyright (c) 2007 Yahoo! Inc.  All rights reserved.  
+# Copyright (c) 2009 Yahoo! Inc.  All rights reserved.  
 # The copyrights to the contents of this file are licensed under the Perl Artistic License (ver. 15 Aug 1997) 
 
 use strict; use warnings;
@@ -14,8 +14,10 @@ Yahoo::Marketing::ForecastResponse - an object to represent a Yahoo Marketing Fo
 
 sub _user_setable_attributes {
     return ( qw/ 
+                 errors
                  forecastLandscape
                  forecastResponseDetail
+                 operationSucceeded
                  warnings
             /  );
 }
@@ -33,7 +35,7 @@ __PACKAGE__->mk_accessors( __PACKAGE__->_user_setable_attributes,
 1;
 =head1 SYNOPSIS
 
-See L<http://searchmarketing.yahoo.com/developer/docs/V4/reference/dataObjects.php> for documentation of the various data objects.
+See L<http://searchmarketing.yahoo.com/developer/docs/V5/reference/dataObjects.php> for documentation of the various data objects.
 
 
 =cut
@@ -48,8 +50,10 @@ Creates a new instance
 
 =over 8
 
+    errors
     forecastLandscape
     forecastResponseDetail
+    operationSucceeded
     warnings
 
 =back
